==> istio-model-v1beta1-6.0.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsSimpleFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsSimpleFluentImpl<A extends LoadBalancerSettingsSimpleFluent<A>> extends BaseFluent<A> implements LoadBalancerSettingsSimpleFluent<A>{
  public LoadBalancerSettingsSimpleFluentImpl() {
  }
  public LoadBalancerSettingsSimpleFluentImpl(LoadBalancerSettingsSimple instance) {
    this.withSimple(instance.getSimple()); 
  }
  private LoadBalancerSettingsSimpleLB simple;
  public LoadBalancerSettingsSimpleLB getSimple() {
    return this.simple;
  }
  public A withSimple(LoadBalancerSettingsSimpleLB simple) {
    this.simple=simple; return (A) this;
  }
  public Boolean hasSimple() {
    return this.simple != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LoadBalancerSettingsSimpleFluentImpl that = (LoadBalancerSettingsSimpleFluentImpl) o;
    if (simple != null ? !simple.equals(that.simple) :that.simple != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(simple,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (simple != null) { sb.append("simple:"); sb.append(simple); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsSimpleFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsSimpleFluentImpl<A extends LoadBalancerSettingsSimpleFluent<A>> extends BaseFluent<A> implements LoadBalancerSettingsSimpleFluent<A>{
  public LoadBalancerSettingsSimpleFluentImpl() {
  }
  public LoadBalancerSettingsSimpleFluentImpl(LoadBalancerSettingsSimple instance) {
    if (instance != null) {
      this.withSimple(instance.getSimple());
    }
  }
  private LoadBalancerSettingsSimpleLB simple;
  public LoadBalancerSettingsSimpleLB getSimple() {
    return this.simple;
  }
  public A withSimple(LoadBalancerSettingsSimpleLB simple) {
    this.simple=simple; return (A) this;
  }
  public Boolean hasSimple() {
    return this.simple != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsSimpleFluentImpl that = (LoadBalancerSettingsSimpleFluentImpl) o;
    if (!java.util.Objects.equals(simple, that.simple)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(simple,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (simple != null) { sb.append("simple:"); sb.append(simple); }
    sb.append("}");
    return sb.toString();
  }
  
}
